@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dune" "3.21.1"
+(define-package "dune" "20250903.1130"
   "Integration with the dune build system."
   ()
   :url "https://github.com/ocaml/dune"
-  :commit "0b5863d9be475453b3cc2bd321fde222af2544d4"
-  :revdesc "3.21.1-0-g0b5863d9be47")
+  :commit "1e54fd3f450aae7fb41ffb6b7c8b7a5aed754777"
+  :revdesc "1e54fd3f450a")
